Properties Methods Events Direct Link

# Class Ext.calendar.DayViewTemplate

Package: | Ext.calendar
Defined In: | DayViewTemplate.js
Class: | DayViewTemplate
Extends: | Object

This is the template used to render the all-day event container used in DayView and WeekView. Internally this class simply defers to instances of Ext.calerndar.DayHeaderTemplate and Ext.calerndar.DayBodyTemplate to perform the actual rendering logic, but it also provides the overall calendar view container that contains them both. As such this is the template that should be used when rendering day or week views.

This template is automatically bound to the underlying event store by the calendar components and expects records of type Ext.calendar.EventRecord.

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.